@@ -6,6 +6,7 @@ import types
 import socket
 import fcntl
 import struct
+import logging
 
 class Result(object):
     def __init__(self, generators, args):
@@ -156,7 +157,7 @@ class ResultsGenerator(object):
                     for friend_id in user_[2]['ids']:
                         myfriends.append([friend_id, user_[0]['id']])
                 except:
-                    loggin.info(user_[0])
+                    logging.info(user_[0])
                     pass
 
         return (myfollowers, myfriends)
